BlockChainContextRequest

Enum BlockChainContextRequest 

pub enum BlockChainContextRequest {
Show 16 variants CurrentRxVms, BatchGetDifficulties(Vec<(u64, HardFork)>), NewRXVM(([u8; 32], Arc<RandomXVm>)), Update(NewBlockData), PopBlocks { numb_blocks: usize, }, HardForkInfos, FeeEstimate { grace_blocks: u64, }, RctOutputDistribution { from_height: u64, to_height: Option<NonZero<u64>>, cumulative: bool, }, CalculatePow { hardfork: HardFork, height: usize, block: Box<Block>, seed_hash: [u8; 32], }, ClearAltCache, AltChains, AltChainContextCache { prev_id: [u8; 32], _token: AltChainRequestToken, }, AltChainDifficultyCache { prev_id: [u8; 32], _token: AltChainRequestToken, }, AltChainWeightCache { prev_id: [u8; 32], _token: AltChainRequestToken, }, AltChainRxVM { height: usize, chain: Chain, _token: AltChainRequestToken, }, AddAltChainContextCache { cache: Box<AltChainContextCache>, _token: AltChainRequestToken, },
}
A request to the blockchain context cache.

Variants



CurrentRxVms

Gets all the current RandomX VMs.



BatchGetDifficulties(Vec<(u64, HardFork)>)

Get the next difficulties for these blocks.

Inputs: a list of block timestamps and hfs

The number of difficulties returned will be one more than the number of timestamps/ hfs.



NewRXVM(([u8; 32], Arc<RandomXVm>))

Add a VM that has been created outside of the blockchain context service to the blockchain context. This is useful when batch calculating POW as you may need to create a new VM if you batch a lot of blocks together, it would be wasteful to then not give this VM to the context service to then use when it needs to init a VM with the same seed.

This should include the seed used to init this VM and the VM.



Update(NewBlockData)

A request to add a new block to the cache.



PopBlocks

Pop blocks from the cache to the specified height.

Fields

numb_blocks: usize

The number of blocks to pop from the top of the chain.

Panics

This will panic if the number of blocks will pop the genesis block.



HardForkInfos

Get information on all hardforks.



FeeEstimate

Get the current fee estimate.

Fields

grace_blocks: u64

TODO



RctOutputDistribution

Get the RCT output distribution.

Fields

from_height: u64

The height to start the distribution from.

to_height: Option<NonZero<u64>>

The height to end the distribution at, None means the top block.

cumulative: bool

Whether the distribution should be cumulative.



CalculatePow

Calculate proof-of-work for this block.

Fields

hardfork: HardFork

The hardfork of the protocol at this block height.

height: usize

The height of the block.

block: Box<Block>

The block data.

This is boxed because [Block] causes this enum to be 1200 bytes, where the 2nd variant is only 96 bytes.

seed_hash: [u8; 32]

The seed hash for the proof-of-work.



ClearAltCache

Clear the alt chain context caches.



AltChains

Get information on all the current alternate chains.



AltChainContextCache

A request for an alt chain context cache.

This variant is private and is not callable from outside this crate, the block verifier service will handle getting the alt cache.

Fields

prev_id: [u8; 32]

The previous block field in a BlockHeader.

_token: AltChainRequestToken

An internal token to prevent external crates calling this request.



AltChainDifficultyCache

A request for a difficulty cache of an alternative chain.

This variant is private and is not callable from outside this crate, the block verifier service will handle getting the difficulty cache of an alt chain.

Fields

prev_id: [u8; 32]

The previous block field in a BlockHeader.

_token: AltChainRequestToken

An internal token to prevent external crates calling this request.



AltChainWeightCache

A request for a block weight cache of an alternative chain.

This variant is private and is not callable from outside this crate, the block verifier service will handle getting the weight cache of an alt chain.

Fields

prev_id: [u8; 32]

The previous block field in a BlockHeader.

_token: AltChainRequestToken

An internal token to prevent external crates calling this request.



AltChainRxVM

A request for a RX VM for an alternative chain.

Response variant: BlockChainContextResponse::AltChainRxVM.

This variant is private and is not callable from outside this crate, the block verifier service will handle getting the randomX VM of an alt chain.

Fields

height: usize

The height the RandomX VM is needed for.

chain: Chain

The chain to look in for the seed.

_token: AltChainRequestToken

An internal token to prevent external crates calling this request.



AddAltChainContextCache

A request to add an alt chain context cache to the context cache.

This variant is private and is not callable from outside this crate, the block verifier service will handle returning the alt cache to the context service.

Fields

cache: Box<AltChainContextCache>

The cache.

_token: AltChainRequestToken

An internal token to prevent external crates calling this request.