AltChainContextCache

Struct AltChainContextCache 

pub struct AltChainContextCache {
    pub weight_cache: Option<BlockWeightsCache>,
    pub difficulty_cache: Option<DifficultyCache>,
    pub cached_rx_vm: Option<(usize, Arc<RandomXVm>)>,
    pub chain_height: usize,
    pub top_hash: [u8; 32],
    pub chain_id: Option<ChainId>,
    pub parent_chain: Chain,
}
The context cache of an alternative chain.

Fields

weight_cache: Option<BlockWeightsCache>

The alt chain weight cache, None if it has not been built yet.

difficulty_cache: Option<DifficultyCache>

The alt chain difficulty cache, None if it has not been built yet.

cached_rx_vm: Option<(usize, Arc<RandomXVm>)>

A cached RX VM.

chain_height: usize

The chain height of the alt chain.

top_hash: [u8; 32]

The top hash of the alt chain.

chain_id: Option<ChainId>

The [ChainId] of the alt chain.

parent_chain: Chain

The parent [Chain] of this alt chain.

Implementations

Source

impl AltChainContextCache

pub fn add_new_block( &mut self, height: usize, block_hash: [u8; 32], block_weight: usize, long_term_block_weight: usize, timestamp: u64, cumulative_difficulty: u128, )

Add a new block to the cache.