pub struct AltChainRequestToken;Expand description
A token that should be hard to create from outside this crate.
It is currently possible to safely create this from outside this crate, DO NOT rely on this as it will be broken once we find a way to completely seal this.